(* $Id: markup_dtd.mli,v 1.1 2000/05/29 23:43:51 gerd Exp $
 * ----------------------------------------------------------------------
 * Markup! The validating XML parser for Objective Caml.
 * Copyright 1999 by Gerd Stolpmann. See LICENSE for details.
 *
 * THIS IS THE markup-0.2.10 COMPATIBLE INTERFACE TO markup_dtd.mli.
 * It corresponds to revision 1.11 of markup_dtd.mli.
 *)

(**********************************************************************)
(*                                                                    *)
(* Markup_dtd:                                                        *)
(*     Object model of document type declarations                     *)
(*                                                                    *)
(**********************************************************************)

(* ======================================================================
 * OVERVIEW
 *
 * class dtd ............... represents the whole DTD, including element
 *                           declarations, entity declarations, notation
 *                           declarations, and processing instructions
 * class dtd_element ....... represents an element declaration consisting
 *                           of a content model and an attribute list
 *                           declaration
 * class dtd_notation ...... represents a notation declaration
 * class proc_instruction .. represents a processing instruction
 * ======================================================================
 *
 *)


class dtd :
  Markup_types.collect_warnings -> 
  Pxp_dtd.dtd
    (* Incompatibilities:
     * add_gen_entity, gen_entity
     *)

class dtd_element : dtd -> string -> Pxp_dtd.dtd_element
  (* Incompatibilities:
   * set_content_model, add_attribute
   *)

class dtd_notation : string -> Markup_types.ext_id -> Pxp_dtd.dtd_notation

class proc_instruction : string -> string -> Pxp_dtd.proc_instruction

(* ======================================================================
 * History:
 * 
 * $Log: markup_dtd.mli,v $
 * Revision 1.1  2000/05/29 23:43:51  gerd
 * 	Initial compatibility revision.
 *
 * ======================================================================
 * OLD LOGS:
 *
 * Revision 1.11  2000/05/29 21:14:57  gerd
 * 	Changed the type 'encoding' into a polymorphic variant.
 *
 * Revision 1.10  2000/05/27 19:20:38  gerd
 * 	Changed the interfaces for the standalone check: New
 * methods: standalone_declaration, set_standalone_declaration,
 * externally_declared, attribute_violates_standalone_declaration.
 * 	The method set_content_model has been renamed to
 * set_cm_and_extdecl; it now initializes also whether the element
 * has been declared in an external entity.
 * 	Methods add_gen_entity and gen_entity pass an additional
 * boolean argument containing whether the declaration of the
 * general entity happened in an external entity.
 * 	Method add_attribute expects this argument, too, which
 * states whether the declaration of the attribute happened in an
 * external entity.
 *
 * Revision 1.9  2000/05/20 20:31:40  gerd
 * 	Big change: Added support for various encodings of the
 * internal representation.
 *
 * Revision 1.8  2000/05/06 23:10:26  gerd
 * 	allow_arbitrary for elements, too.
 *
 * Revision 1.7  2000/05/01 20:42:52  gerd
 *         New method write_compact_as_latin1.
 *
 * Revision 1.6  2000/03/11 22:58:15  gerd
 * 	Updated to support Markup_codewriter.
 *
 * Revision 1.5  2000/02/22 02:32:02  gerd
 * 	Updated.
 *
 * Revision 1.4  1999/11/09 22:15:41  gerd
 * 	Added method "arbitrary_allowed".
 *
 * Revision 1.3  1999/09/01 16:21:56  gerd
 * 	"dtd" classes have now an argument that passes a "warner".
 *
 * Revision 1.2  1999/08/15 02:20:23  gerd
 *         New feature: a DTD can allow arbitrary elements.
 *
 * Revision 1.1  1999/08/10 00:35:51  gerd
 * 	Initial revision.
 *
 * 
 *)
