(* $Id: markup_types.ml,v 1.5 2000/08/18 20:19:16 gerd Exp $
 * ----------------------------------------------------------------------
 *)


type ext_id = Pxp_types.ext_id =
    System of string
  | Public of (string * string)
  | Anonymous
type dtd_id = Pxp_types.dtd_id=
    External of ext_id
  | Derived of ext_id
  | Internal
type content_model_type = Pxp_types.content_model_type =
    Unspecified
  | Empty
  | Any
  | Mixed of mixed_spec list
  | Regexp of regexp_spec
and mixed_spec = Pxp_types.mixed_spec =
    MPCDATA
  | MChild of string
and regexp_spec = Pxp_types.regexp_spec =
    Optional of regexp_spec
  | Repeated of regexp_spec
  | Repeated1 of regexp_spec
  | Alt of regexp_spec list
  | Seq of regexp_spec list
  | Child of string
type att_type = Pxp_types.att_type =
    A_cdata
  | A_id
  | A_idref
  | A_idrefs
  | A_entity
  | A_entities
  | A_nmtoken
  | A_nmtokens
  | A_notation of string list
  | A_enum of string list
type att_default = Pxp_types.att_default =
    D_required
  | D_implied
  | D_default of string
  | D_fixed of string
type att_value = Pxp_types.att_value =
    Value of string
  | Valuelist of string list
  | Implied_value

class collect_warnings = 
object
  val mutable w = Buffer.create 100
  method print_warnings =
    Buffer.contents w
  method reset =
    Buffer.clear w
  method warn s =
    Buffer.add_string w ("WARNING: " ^ s ^ "\n")
end

exception Illegal_character of int
exception Validation_error = Pxp_types.Validation_error
exception WF_error = Pxp_types.WF_error
exception Character_not_supported = Pxp_types.Character_not_supported
exception Bad_character_stream = Netconversion.Malformed_code
exception At = Pxp_types.At
exception Undeclared = Pxp_types.Undeclared

let string_of_exn = Pxp_types.string_of_exn

type output_stream = Pxp_types.output_stream =
    Out_buffer of Buffer.t
  | Out_channel of out_channel
  | Out_function of (string -> int -> int -> unit)

let write = Pxp_types.write


(* ======================================================================
 * History:
 * 
 * $Log: markup_types.ml,v $
 * Revision 1.5  2000/08/18 20:19:16  gerd
 * 	Updates in the emulation because of PXP changes.
 *
 * Revision 1.4  2000/07/16 18:30:15  gerd
 * 	Updated because PXP does no longer have the exception
 * Illegal_character.
 *
 * Revision 1.3  2000/07/14 21:35:35  gerd
 * 	Updated because of the simplification of Pxp_types.collect_warnings.
 *
 * Revision 1.2  2000/07/08 17:40:50  gerd
 * 	Updated the simulation.
 *
 * Revision 1.1  2000/05/29 23:43:51  gerd
 * 	Initial compatibility revision.
 *
 *)
