(* $Id: markup_types.mli,v 1.2 2000/07/08 17:40:50 gerd Exp $
 * ----------------------------------------------------------------------
 * Markup! The validating XML parser for Objective Caml.
 * Copyright 1999 by Gerd Stolpmann. See LICENSE for details.
 *
 * THIS IS THE markup-0.2.10 COMPATIBLE INTERFACE TO markup_types.mli.
 * It corresponds to revision 1.7 of markup_types.mli.
 *)


type ext_id = Pxp_types.ext_id =
    System of string
  | Public of (string * string)
  | Anonymous
type dtd_id = Pxp_types.dtd_id =
    External of ext_id
  | Derived of ext_id
  | Internal
type content_model_type = Pxp_types.content_model_type =
    Unspecified
  | Empty
  | Any
  | Mixed of mixed_spec list
  | Regexp of regexp_spec
and mixed_spec = Pxp_types.mixed_spec =
    MPCDATA
  | MChild of string
and regexp_spec = Pxp_types.regexp_spec =
    Optional of regexp_spec
  | Repeated of regexp_spec
  | Repeated1 of regexp_spec
  | Alt of regexp_spec list
  | Seq of regexp_spec list
  | Child of string
type att_type = Pxp_types.att_type =
    A_cdata
  | A_id
  | A_idref
  | A_idrefs
  | A_entity
  | A_entities
  | A_nmtoken
  | A_nmtokens
  | A_notation of string list
  | A_enum of string list
type att_default = Pxp_types.att_default =
    D_required
  | D_implied
  | D_default of string
  | D_fixed of string
type att_value = Pxp_types.att_value =
    Value of string
  | Valuelist of string list
  | Implied_value

class collect_warnings :
  object 
    method warn : string -> unit
    method print_warnings : string
    method reset : unit
  end
;;


exception Illegal_character of int
exception Validation_error of string
exception WF_error of string
exception Character_not_supported
exception Bad_character_stream
exception At of (string * exn)
exception Undeclared

val string_of_exn : exn -> string
  (* Converts a Markup exception into a readable string *)


type output_stream = Pxp_types.output_stream =
    Out_buffer of Buffer.t
  | Out_channel of out_channel
  | Out_function of (string -> int -> int -> unit)

val write : output_stream -> string -> int -> int -> unit
  (* write os s pos len: Writes the string to the buffer/channel/stream *)

(* ======================================================================
 * History:
 * 
 * $Log: markup_types.mli,v $
 * Revision 1.2  2000/07/08 17:40:50  gerd
 * 	Updated the simulation.
 *
 * Revision 1.1  2000/05/29 23:43:51  gerd
 * 	Initial compatibility revision.
 *
 * ======================================================================
 * OLD LOGS:
 *
 * Revision 1.7  2000/05/29 21:14:57  gerd
 * 	Changed the type 'encoding' into a polymorphic variant.
 *
 * Revision 1.6  2000/05/20 20:31:40  gerd
 * 	Big change: Added support for various encodings of the
 * internal representation.
 *
 * Revision 1.5  2000/05/01 20:43:25  gerd
 *         New type output_stream; new function 'write'.
 *
 * Revision 1.4  1999/09/01 16:25:35  gerd
 * 	Dropped Illegal_token and Content_not_allowed_here. WF_error can
 * be used instead.
 *
 * Revision 1.3  1999/08/15 02:22:40  gerd
 *         Added exception Undeclared.
 *
 * Revision 1.2  1999/08/14 22:15:17  gerd
 *         New class "collect_warnings".
 *
 * Revision 1.1  1999/08/10 00:35:52  gerd
 * 	Initial revision.
 *
 * 
 *)
